==> v0.15.zip: chrono/chrono/manager/urls.py <==
# chrono - agendas system
# Copyright (C) 2016  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf.urls import patterns, url

from . import views

urlpatterns = patterns('chrono.views',
        url(r'^$', views.homepage, name='chrono-manager-homepage'),
        url(r'^agendas/add/$', views.agenda_add,
            name='chrono-manager-agenda-add'),
        url(r'^agendas/(?P<pk>\w+)/$', views.agenda_view,
            name='chrono-manager-agenda-view'),
        url(r'^agendas/(?P<pk>\w+)/edit$', views.agenda_edit,
            name='chrono-manager-agenda-edit'),
        url(r'^agendas/(?P<pk>\w+)/delete$', views.agenda_delete,
            name='chrono-manager-agenda-delete'),
        url(r'^agendas/(?P<pk>\w+)/add-event$', views.agenda_add_event,
            name='chrono-manager-agenda-add-event'),
        url(r'^agendas/(?P<pk>\w+)/import-events$', views.agenda_import_events,
            name='chrono-manager-agenda-import-events'),
        url(r'^events/(?P<pk>\w+)/$', views.event_edit,
            name='chrono-manager-event-edit'),
        url(r'^events/(?P<pk>\w+)/delete$', views.event_delete,
            name='chrono-manager-event-delete'),

        url(r'^agendas/(?P<pk>\w+)/add-meeting-type$', views.agenda_add_meeting_type,
            name='chrono-manager-agenda-add-meeting-type'),
        url(r'^meetingtypes/(?P<pk>\w+)/edit$', views.meeting_type_edit,
            name='chrono-manager-meeting-type-edit'),
        url(r'^meetingtypes/(?P<pk>\w+)/delete$', views.meeting_type_delete,
            name='chrono-manager-meeting-type-delete'),

        url(r'^agendas/(?P<pk>\w+)/add-time-period$', views.agenda_add_time_period,
            name='chrono-manager-agenda-add-time-period'),
        url(r'^timeperiods/(?P<pk>\w+)/edit$', views.time_period_edit,
            name='chrono-manager-time-period-edit'),
        url(r'^timeperiods/(?P<pk>\w+)/delete$', views.time_period_delete,
            name='chrono-manager-time-period-delete'),

        url(r'^agendas/events.csv$', views.agenda_import_events_sample_csv,
            name='chrono-manager-sample-events-csv'),

        url(r'^menu.json$', views.menu_json),
)

==> v0.20.zip: chrono/chrono/manager/urls.py <==
# chrono - agendas system
# Copyright (C) 2016  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf.urls import url

from . import views

urlpatterns = [
        url(r'^$', views.homepage, name='chrono-manager-homepage'),
        url(r'^agendas/add/$', views.agenda_add,
            name='chrono-manager-agenda-add'),
        url(r'^agendas/(?P<pk>\w+)/$', views.agenda_view,
            name='chrono-manager-agenda-view'),
        url(r'^agendas/(?P<pk>\w+)/edit$', views.agenda_edit,
            name='chrono-manager-agenda-edit'),
        url(r'^agendas/(?P<pk>\w+)/delete$', views.agenda_delete,
            name='chrono-manager-agenda-delete'),
        url(r'^agendas/(?P<pk>\w+)/add-event$', views.agenda_add_event,
            name='chrono-manager-agenda-add-event'),
        url(r'^agendas/(?P<pk>\w+)/import-events$', views.agenda_import_events,
            name='chrono-manager-agenda-import-events'),
        url(r'^events/(?P<pk>\w+)/$', views.event_edit,
            name='chrono-manager-event-edit'),
        url(r'^events/(?P<pk>\w+)/delete$', views.event_delete,
            name='chrono-manager-event-delete'),

        url(r'^agendas/(?P<pk>\w+)/add-meeting-type$', views.agenda_add_meeting_type,
            name='chrono-manager-agenda-add-meeting-type'),
        url(r'^meetingtypes/(?P<pk>\w+)/edit$', views.meeting_type_edit,
            name='chrono-manager-meeting-type-edit'),
        url(r'^meetingtypes/(?P<pk>\w+)/delete$', views.meeting_type_delete,
            name='chrono-manager-meeting-type-delete'),

        url(r'^agendas/(?P<pk>\w+)/add-time-period$', views.agenda_add_time_period,
            name='chrono-manager-agenda-add-time-period'),
        url(r'^timeperiods/(?P<pk>\w+)/edit$', views.time_period_edit,
            name='chrono-manager-time-period-edit'),
        url(r'^timeperiods/(?P<pk>\w+)/delete$', views.time_period_delete,
            name='chrono-manager-time-period-delete'),

        url(r'^agendas/events.csv$', views.agenda_import_events_sample_csv,
            name='chrono-manager-sample-events-csv'),

        url(r'^menu.json$', views.menu_json),
]
